@@ -9,11 +9,11 @@ from .Prior import Prior
 from .UniformPrior import UniformPrior
 
 __author__ = "Do Kester"
-__year__ = 2018
+__year__ = 2020
 __license__ = "GPL3"
-__version__ = "0.9"
-__maintainer__ = "Do"
-__status__ = "Development"
+__version__ = "2.5.3"
+__url__ = "https://www.bayesicfitting.nl"
+__status__ = "Perpetual Beta"
 
 #  * This file is part of the BayesicFitting package.
 #  *
@@ -163,13 +163,19 @@ class BaseModel( object ):
         name : string
             name of the attribute
         """
-        if name == "parNames" :
+        if name == "priors" :
+            return None
+
+        elif name == "parNames" :
+#        if name == "parNames" :
             raise AttributeError( "Model has no defined parameter names." )
 
         for k,pn in enumerate( self.parNames ) :
             if name == pn :
                 return self.parameters[k]
 
+        ## Raise error for any remaining attributes, not found standardly
+        raise AttributeError( "Model has no attribute %s." % name )
 
 
     #  *****RESULT**************************************************************
@@ -324,6 +330,7 @@ class BaseModel( object ):
             return
 
         self.priors[k] = prior
+
         return
 
     def hasPriors( self, isBound=True ) :
