@@ -5,11 +5,11 @@ from .Engine import Engine
 from .Formatter import formatter as fmt
 
 __author__ = "Do Kester"
-__year__ = 2018
+__year__ = 2020
 __license__ = "GPL"
-__version__ = "1.0"
-__maintainer__ = "Do"
-__status__ = "Development"
+__version__ = "2.6.2"
+__url__ = "https://www.bayesicfitting.nl"
+__status__ = "Perpetual Beta"
 
 #  *
 #  * This file is part of the BayesicFitting package.
@@ -75,32 +75,36 @@ class BirthEngine( Engine ):
         return str( "BirthEngine" )
 
     #  *********EXECUTE***************************************************
-    def execute( self, walker, lowLhood ):
+    def execute( self, kw, lowLhood, append=False, iteration=0 ):
         """
         Execute the engine by adding a component and diffusing the parameters.
 
         Parameters
         ----------
-        walker : Sample
-            walker to diffuse
+        kw : int
+            index of walker to diffuse
         lowLhood : float
             lower limit in logLikelihood
+        append : bool
+            set walker in place or append
+        iteration : int
+            iteration number
 
         Returns
         -------
         int : the number of successfull moves
 
         """
+        self.reportCall()
+
+        walker = self.walkers[kw].copy()            ## work on local copy.
+
         nhyp = self.errdis.nphypar
         walker.problem.model.parameters = walker.allpars[:-nhyp]
 
-        self.reportCall()
-
-        cwalker = walker.copy()                  ## work on local copy.
-
-        problem = cwalker.problem
-        allp = cwalker.allpars
-        ftry = cwalker.fitIndex
+        problem = walker.problem
+        allp = walker.allpars
+        ftry = walker.fitIndex
 
         if self.verbose > 4 :
             print( "BEN0  ", walker.id, walker.parent, len( allp ), len( ftry ) )
@@ -117,7 +121,7 @@ class BirthEngine( Engine ):
         np = model.npbase
 
         if self.verbose > 4 :
-            print( "BEN1  ", cwalker.id, nc, np, len( allp ), len( ftry ) )
+            print( "BEN1  ", walker.id, nc, np, len( allp ), len( ftry ) )
 
         if not ( nc < model.growPrior.unit2Domain( self.rng.rand() ) and
                  model.grow( offset=off, rng=self.rng ) ):
@@ -144,8 +148,9 @@ class BirthEngine( Engine ):
 
             if Ltry >= lowLhood:
                 self.reportSuccess()
-                self.setWalker( cwalker, problem, ptry, Ltry, fitIndex=ftry )
-                wlkr = self.walkers[walker.id]
+                update = len( self.walkers ) if append else kw
+                self.setWalker( update, problem, ptry, Ltry, fitIndex=ftry )
+                wlkr = self.walkers[update]
                 wlkr.check( nhyp=nhyp )
                 return dnp
             else :
