@@ -6,11 +6,11 @@ from .Dynamic import Dynamic
 from .Engine import Engine
 
 __author__ = "Do Kester"
-__year__ = 2018
+__year__ = 2020
 __license__ = "GPL"
-__version__ = "1.0"
-__maintainer__ = "Do"
-__status__ = "Development"
+__version__ = "2.6.2"
+__url__ = "https://www.bayesicfitting.nl"
+__status__ = "Perpetual Beta"
 
 #  *
 #  * This file is part of the BayesicFitting package.
@@ -77,33 +77,39 @@ class DeathEngine( Engine ):
         return str( "DeathEngine" )
 
     #  *********EXECUTE***************************************************
-    def execute( self, walker, lowLhood ):
+    def execute( self, kw, lowLhood, append=False, iteration=0 ):
         """
         Execute the engine by removins a component.
 
         Parameters
         ----------
-        walker : Walker
-            walker to diffuse
+        kw : int
+            index of walker to diffuse
         lowLhood : float
             lower limit in logLikelihood
+        append : bool
+            set walker in place or append
+        iteration : int
+            iteration number
 
         Returns
         -------
         int : the number of successfull moves
 
         """
+        self.reportCall()
+
+        walker = self.walkers[kw].copy()          ## work on local copy
+
         nhyp = self.errdis.nphypar
         walker.problem.model.parameters = walker.allpars[:-nhyp]
 
-        self.reportCall()
 
-        cwalker = walker.copy()          ## work on local copy
-        problem = cwalker.problem
+        problem = walker.problem
         model = problem.model
-        allp = cwalker.allpars
+        allp = walker.allpars
         ptry = allp
-        ftry = cwalker.fitIndex
+        ftry = walker.fitIndex
 
         off = 0
         while model is not None and not isinstance( model, Dynamic ) :
@@ -114,7 +120,7 @@ class DeathEngine( Engine ):
         np = model.npbase
 
         if self.verbose > 4 :
-            print( "DEN1  ", cwalker.id, nc, np, len( ptry ), len( ftry ) )
+            print( "DEN1  ", walker.id, nc, np, len( ptry ), len( ftry ) )
 
         # shuffle the parameters (if needed) before throwing the last one out.
         ptry = model.shuffle( ptry, off, np, self.rng )
@@ -136,8 +142,9 @@ class DeathEngine( Engine ):
 
         if Ltry >= lowLhood:
             self.reportSuccess()
-            self.setWalker( cwalker, problem, ptry, Ltry, fitIndex=ftry )
-            wlkr = self.walkers[walker.id]
+            update = len( self.walkers ) if append else kw
+            self.setWalker( update, problem, ptry, Ltry, fitIndex=ftry )
+            wlkr = self.walkers[update]
             wlkr.check( nhyp=nhyp )
             return abs( dnp )
 
