@@ -1,6 +1,7 @@
 import numpy as numpy
 from astropy import units
 import re
+import string
 import warnings
 from . import Tools
 
@@ -8,11 +9,11 @@ from .BaseModel import BaseModel
 from .Tools import setAttribute as setatt
 
 __author__ = "Do Kester"
-__year__ = 2018
+__year__ = 2020
 __license__ = "GPL3"
-__version__ = "0.9"
-__maintainer__ = "Do"
-__status__ = "Development"
+__version__ = "2.6.0"
+__url__ = "https://www.bayesicfitting.nl"
+__status__ = "Perpetual Beta"
 
 #  * This file is part of the BayesicFitting package.
 #  *
@@ -106,6 +107,12 @@ class FixedModel( BaseModel ):
         mlist = []
         npar = nparams
         if fixed is not None :
+            for k in fixed.keys() :
+                if k < 0 :                  # convert negative indices into positive ones
+                    val = fixed[k]
+                    del( fixed[k] )
+                    k += npar
+                    fixed[k] = val
             for k in fixed.keys() :
                 if isinstance( fixed[k], BaseModel ) :
                     mlist += [k]
@@ -243,6 +250,7 @@ class FixedModel( BaseModel ):
             return param
 
         pars = numpy.zeros( self._npb, dtype=float )
+
         pars[self.parlist] = param
         if len( self.mlist ) == 0 :
             fl =  list( self.fixed.keys() )
@@ -423,33 +431,52 @@ class FixedModel( BaseModel ):
     def _toString( self, npars=0 ) :
         basename = self.baseName()
 
+#        print( "FM %d  " % npars, basename )
+
         if self.fixed is not None :
             for k in self.fixed.keys() :
-                par = "p_%d "%k
+                par = r"p_%d([^0-9]|$)"%k
                 if k in self.mlist :
-                    val = "(%s) " % self.fixed[k].shortName()
+                    val = r"(%s) " % self.fixed[k].shortName()
                 else :
-                    val = "(%.1f) "%self.fixed[k]
+                    val = r"(%.1f) "%self.fixed[k]
                 basename = re.sub( par, val, basename )
+#            print( "FM1   ", basename )
+#            print( "ParL  ", self.parlist )
             i = 0
-            par = "q_0 "
             for k in self.parlist :
-                old = "p_%d "%k
+                old = r"p_%d([^0-9]|$)"%k
+                par = r"q_%d\1"%i
                 basename = re.sub( old, par, basename )
                 i += 1
-                par = "q_%d "%i
-            basename = re.sub( "q_", "p_", basename )
+#                print( "FM    ", basename )
+            basename = re.sub( r"q_", r"p_", basename )
+
+#        print( "FM2   ", basename )
+
 
         if npars == 0 : return basename
-        k = 0
-        par0 = "p_0"
-        par1 = "q_%d"%(k+npars)
-        while re.search( par0, basename ) :
-            basename = re.sub( par0, par1, basename )
-            k += 1
-            par0 = "p_%d "%k
-            par1 = "q_%d "%(k+npars)
-        basename = re.sub( "q_", "p_", basename )
+
+#        print( "FM11  ", basename )
+
+        i = 0
+        while True :
+            mo = re.search( r'p_([0-9]*)', basename, flags=re.MULTILINE )
+            if mo is None : break
+
+            span = mo.span()
+            k = int( basename[span[0]+2:span[1]] )
+#            print( "FM    ", span, k, npars )
+            basename = re.sub( r'p_%d'%k, r'q_%d'%(k+npars), basename, flags=re.MULTILINE )
+
+
+#        print( "FM12  ", basename )
+
+        basename = basename.replace( "q_", "p_" )
+
+#        print( "FM13  ", basename )
+
         return basename
 
 
+
