@@ -10,11 +10,11 @@ from .Engine import Engine
 from .Engine import DummyPlotter
 
 __author__ = "Do Kester"
-__year__ = 2018
+__year__ = 2020
 __license__ = "GPL3"
-__version__ = "0.9"
-__maintainer__ = "Do"
-__status__ = "Development"
+__version__ = "2.6.2"
+__url__ = "https://www.bayesicfitting.nl"
+__status__ = "Perpetual Beta"
 
 #  *
 #  * This file is part of the BayesicFitting package.
@@ -57,8 +57,10 @@ class GalileanEngine( Engine ):
 
     """
 
+    SIZE = 0.5
+
     #  *********CONSTRUCTORS***************************************************
-    def __init__( self, walkers, errdis, slow=None, copy=None, seed=4213, verbose=0 ):
+    def __init__( self, walkers, errdis, copy=None, **kwargs ):
         """
         Default Constructor.
 
@@ -68,16 +70,16 @@ class GalileanEngine( Engine ):
             walkers to be diffused
         errdis : ErrorDistribution
             error distribution to be used
-        slow : None or int > 0
-            Run this engine every slow-th iteration. None for all.
         copy : GalileanEngine
             to be copied
-        seed : int
-            for random number generator
+        kwargs : for Engine
+            "slow", "seed", "verbose"
+
         """
-        super( ).__init__( walkers, errdis, slow=slow, copy=copy,
-                        seed=seed, verbose=verbose  )
+        super( ).__init__( walkers, errdis, copy=copy, **kwargs )
+
         self.nstep = 5
+        self.size = self.SIZE
 
         self.plotter = DummyPlotter( )
 
@@ -93,25 +95,31 @@ class GalileanEngine( Engine ):
         return str( "GalileanEngine" )
 
     #  *********EXECUTE***************************************************
-    def execute( self, walker, lowLhood ):
+    def execute( self, kw, lowLhood, append=False, iteration=0 ):
         """
         Execute the engine by diffusing the parameters.
 
         Parameters
         ----------
-        walker : Sample
-            walker to diffuse
+        kw : int
+            index in walkerlist, of the walker
         lowLhood : float
             lower limit in logLikelihood
+        append : bool
+            set walker in place of append
 
         Returns
         -------
         int : the number of successfull moves
 
         """
+#        if iteration >= 1755 :
+#            self.verbose = 5
+
+
         self.reportCall()
 
-        walker = walker.copy()
+        walker = self.walkers[kw].copy()
         problem = walker.problem
         Lhood = walker.logL
         allpars = walker.allpars
@@ -120,9 +128,9 @@ class GalileanEngine( Engine ):
         npout = 0
         inside = 0
         Ltry = 0
-        size = 0.5
+        size = self.size
 
-        self.plotter.start( )
+        self.plotter.start( param=allpars )
         um = UnitMovements( walker, self, size )
 
         nstep = int( self.nstep * ( 1 + self.rng.rand() ) )
@@ -131,11 +139,12 @@ class GalileanEngine( Engine ):
 
         ptry = allpars.copy()
         if self.verbose > 4 :
-            print( "alpar ", fma( ptry ), fmt( Lhood ), fmt( lowLhood) )
+            print( "LogL  ", fmt( Lhood ), " LowL  ", fmt( lowLhood), nstep, maxtrial, size )
+            print( "alpar ", fma( ptry, linelength=200 ) )
             fip = allpars[fitIndex]
-            print( "uap   ", fma( self.domain2Unit( problem, fip, fitIndex )))
-            print( "fitin ", fma( fitIndex ), nstep, maxtrial )
-            print( "unitr ", fma( self.unitRange ), size )
+            print( "uap   ", fma( self.domain2Unit( problem, fip, fitIndex ), linelength=200) )
+#            print( "fitin ", fma( fitIndex, linelength=200 ) )
+            print( "unitr ", fma( self.unitRange, linelength=200 ), self.unitRange[-2] )
 
         step = 0
         trial = 0
@@ -177,6 +186,10 @@ class GalileanEngine( Engine ):
 
             Ltry = self.errdis.logLikelihood( problem, ptry )
 
+            if self.verbose > 4 :
+                print( "uval  ", fma( um.upar, linelength=200 ) )
+#                print( "Ltry  ", Ltry, "  Lowl  ", lowLhood, self.walkers[-1].logL )
+
             if Ltry >= lowLhood:
                 self.plotter.move( allpars, ptry, col=0, sym=0 )
 
@@ -188,12 +201,9 @@ class GalileanEngine( Engine ):
                 step += 1
                 trial = 0
 
-                ## check if better than Lbest in walkers[-1]
-                self.checkBest( problem, ptry, Ltry, fitIndex )
-
                 ## update the walker
-                self.setWalker( walker, problem, allpars, Lhood, fitIndex=fitIndex )
-
+                update = len( self.walkers ) if append else kw
+                self.setWalker( update, problem, allpars, Lhood, fitIndex=fitIndex )
 
             else:
                 inside += 1
@@ -205,24 +215,23 @@ class GalileanEngine( Engine ):
                     self.reportFailed( )
 
             if self.verbose > 4 :
-                print( "GEng  ", fma(ptry), fmt(Ltry), inside, step, trial, fmt( size ) )
+                print( "GEng  ", fma(ptry, linelength=200) )
+                print( "Ltry  ", fmt(Ltry), inside, step, trial, fmt( size ) )
+
 
             if not ( step < nstep and trial < maxtrial ):
                 break
 
-#        if npout > 0 :
-#            self.setWalker( walker, problem, allpars, Lhood, fitIndex=fitIndex )
-#        elif self.verbose > 4 :
 
 
-        if npout == 0 and self.verbose > 4 :
-            warnings.warn( "GalileanEngine: no steps found" )
+        if npout == 0 :
+            self.size = max( 0.9 * self.size, 1e-6 )
+            if self.verbose > 4 :
+                warnings.warn( "GalileanEngine: no steps found" )
+        else :
+            self.size = min( self.SIZE, self.size * 1.1 )
 
-#        if npout == 0 :
-#            print( "Galilean ", walker.id, trial, step, npout, fma( ptry ) )
-
-
-        self.plotter.stop()
+        self.plotter.stop( param=allpars, name="GalileanEngine" )
         return npout
 
 class UnitMovements( object ):
@@ -264,6 +273,8 @@ class UnitMovements( object ):
         Return a new stepped parameter set.
         """
         uv = self.uvel
+        # add small random contribution to velocity
+        uv *= 1 + ( self.uniform() * 0.1 )
         pv = self.upar + uv * f
 
         # check if outside [0,1]
