@@ -3,11 +3,11 @@ from scipy import special
 from .Prior import Prior
 
 __author__ = "Do Kester"
-__year__ = 2017
+__year__ = 2020
 __license__ = "GPL3"
-__version__ = "0.9"
-__maintainer__ = "Do"
-__status__ = "Development"
+__version__ = "2.6.2"
+__url__ = "https://www.bayesicfitting.nl"
+__status__ = "Perpetual Beta"
 
 #  * This file is part of the BayesicFitting package.
 #  *
@@ -41,6 +41,13 @@ class GaussPrior( Prior ):
     domain2unit: u = 0.5 * ( erf( ( d - center ) / scale ) + 1 )
     unit2domain: d = erfinv( 2 * u - 1 ) * scale + center
 
+    Examples
+    --------
+    >>> pr = GaussPrior()                         # center=0, scale=1
+    >>> pr = GaussPrior( center=1.0, scale=0.5 )
+    >>> pr = GaussPrior( limits=[0,None] )        # limited to values >= 0
+    >>> pr = GaussPrior( center=1, circular=3 )   # circular between 0.5 and 2.5
+
     Attributes
     ----------
     center : float
@@ -50,17 +57,18 @@ class GaussPrior( Prior ):
 
     Attributes from Prior
     --------------------=
-    lowLimit, highLimit, deltaP, _lowDomain, _highDomain
+    lowLimit, highLimit, circular, deltaP, _lowDomain, _highDomain
 
-    lowLimit and highLimit cannot be used in this implementation.
 
     """
 
     SPI = 1.0 / math.sqrt( math.pi )
     LSPI = math.log( SPI )
 
+    MAXVAL = 6
+
     #  *********CONSTRUCTOR***************************************************
-    def __init__( self, center=0.0, scale=1.0, prior=None ):
+    def __init__( self, center=0.0, scale=1.0, limits=None, circular=False, prior=None ):
         """
         Constructor.
 
@@ -70,17 +78,25 @@ class GaussPrior( Prior ):
             of the location of the prior
         scale : float
             of the exponential
+        limits : None or [float,float]
+            None    no limits are set
+            2 floats    lowlimit and highlimit
+        circular : bool or float
+            bool : y|n circular with period from limits[0] to limits[1]
+            float : period of circularity
         prior : GaussPrior
             prior to copy (with new scale if applicable)
 
         """
-        super( GaussPrior, self ).__init__( prior=prior )
         self.center = center
         self.scale = scale
 
+        super( ).__init__( limits=limits, circular=circular, prior=prior )
+
     def copy( self ):
         """ Copy the prior """
-        return GaussPrior( prior=self, center=self.center, scale=self.scale )
+        return GaussPrior( prior=self, center=self.center, scale=self.scale,
+                           limits=self.limits, circular=self.circular )
 
     def domain2Unit( self, dval ):
         """
@@ -110,7 +126,12 @@ class GaussPrior( Prior ):
             value within [0,1]
 
         """
-        return special.erfinv( 2 * uval - 1 ) * self.scale + self.center
+        dom = special.erfinv( 2 * uval - 1 )
+        if math.isfinite( dom ) :
+            return dom * self.scale + self.center
+        else :
+            fs = - self.MAXVAL if uval < 0.5 else self.MAXVAL
+            return self.center + fs * self.scale
 
 #    def partialDomain2Unit( self, dval ):
     def result( self, x ):
@@ -155,9 +176,9 @@ class GaussPrior( Prior ):
         """ Return true if the integral over the prior is bound.  """
         return True
 
-    def __str__( self ):
+    def shortName( self ):
         """ Return a string representation of the prior.  """
-        return str( "Gauss prior with scale = %.2f"%( self.scale ) )
+        return str( "GaussPrior" )
 
 
 
