@@ -13,11 +13,11 @@ from .Formatter import formatter as fmt
 from .Tools import setAttribute as setatt
 
 __author__ = "Do Kester"
-__year__ = 2018
+__year__ = 2020
 __license__ = "GPL3"
-__version__ = "0.9"
-__maintainer__ = "Do"
-__status__ = "Development"
+__version__ = "2.6.0"
+__url__ = "https://www.bayesicfitting.nl"
+__status__ = "Perpetual Beta"
 
 #  * This file is part of the BayesicFitting package.
 #  *
@@ -677,6 +677,7 @@ class Model( FixedModel ):
     def _toString( self, indent, npars=0 ) :
         opname = [" null\n", " +\n", " -\n", " *\n", " /\n", " |\n" ]
         np = self.npbase
+
         if self._next is None :
             return super( Model, self )._toString( npars=npars )
 
@@ -894,6 +895,7 @@ class Model( FixedModel ):
             nh = len( highLimits )
             ml = max( ml, nh )
         if ml == 0 : return
+
         if ml > self.npchain :
             warnings.warn( "More limits given than parameters present: %d < %d" %
                             ( ml, self.npchain ) )
@@ -1403,7 +1405,7 @@ class Brackets( Model ):
         return Brackets( self.model.copy(), copy=self )
 
 
-    #  *****RESULT**************************************************************
+    #  *****Brackets RESULT**************************************************************
     def baseResult( self, xdata, param ):
         """
         Returns the result calculated at the xdatas.
@@ -1418,7 +1420,7 @@ class Brackets( Model ):
         """
         return self.model.result( xdata, param )
 
-    #  *****PARTIAL*************************************************************
+    #  *****Brackets PARTIAL*************************************************************
     def basePartial( self, xdata, param, parlist=None ):
         """
         Returns the partial derivatives calculated at the xdatas.
@@ -1435,7 +1437,7 @@ class Brackets( Model ):
         """
         return self.model.partial( xdata, param )
 
-    #  *****DERIVATIVE***********************************************************
+    #  *****Brackets DERIVATIVE***********************************************************
     def baseDerivative( self, xdata, param ):
         """
         Returns the derivative (df/dx) calculated at the xdatas.
@@ -1460,7 +1462,7 @@ class Brackets( Model ):
     def nextPrior( self ) :
         yield self.model.nextPrior()
 
-    #  *************************************************************************
+    #  ******Brackets BASENAME*******************************************************************
     def baseName( self ):
         """ Returns a string representation of the model.  """
         indent = "  "
@@ -1488,6 +1490,9 @@ class Brackets( Model ):
         """
         return self.model.hasPriors( isBound=isBound )
 
+
+    #  ******Brackets Parameter NAME*******************************************************************
+
     def baseParameterName( self, k ):
         """
         Return the name of the indicated parameter.
