@@ -1,12 +1,16 @@
 import numpy as numpy
 import math as math
+import warnings
+
+from .Tools import setAttribute as setatt
+from .Tools import printclass
 
 __author__ = "Do Kester"
-__year__ = 2018
+__year__ = 2020
 __license__ = "GPL3"
-__version__ = "0.9"
-__maintainer__ = "Do"
-__status__ = "Development"
+__version__ = "2.6.2"
+__url__ = "https://www.bayesicfitting.nl"
+__status__ = "Perpetual Beta"
 
 
 #  *
@@ -33,10 +37,27 @@ __status__ = "Development"
 class Prior( object ):
     """
     Base class defining prior distributions.
-    Most of the lower and upper limit handling is done in this class.
 
-    Two methods need to be defined which map the values between [0,1]
-    on to the domain, and vice versa: unit2Domain and domain2Unit.
+    Two methods need to be defined in specific priors which map
+    the values between [0,1] on to the domain, and vice versa:
+    unit2Domain and domain2Unit.
+
+        u = domain2Unit( d )
+        d = unit2Domain( u )
+
+    d is a value in the domain of the prior and u is a vlue in [0,1]
+
+    The handling of limits is relegated to this Prior class
+
+        u = ( domain2Unit( d ) - umin ) / urange
+        d = unit2Domain( u * urange + umin )
+
+    Symmetric priors can be used in a circular variant; i.e.
+    the low and high limits are folded on each other, provided
+    that the limit values are the same (hence symmetric)
+
+        u = limitedDomain2Unit( d ) + 1 ) / 3
+        d = limitedUnit2Domain( ( u * 3 ) % 1 )
 
     The copy method is also necessary.
 
@@ -48,6 +69,8 @@ class Prior( object ):
         high limit on the Prior
     deltaP : float
         width of numerical partial derivative calculation
+    circular : bool or float
+        whether circular
 
     Hidden Attributes
     -----------------
@@ -55,18 +78,28 @@ class Prior( object ):
         lower limit of the Priors possible values
     _highDomain : float
         upper limit of the Priors possible values
-
+    _umin : float
+        umin lowLimit in unit
+    _urng : float
+        urange (hi-lo) in unit
     """
 
     #*********CONSTRUCTORS***************************************************
-    def __init__( self, limits=None, prior=None ):
+    def __init__( self, limits=None, circular=False, domain=[-math.inf,math.inf],
+                  prior=None ):
         """
         Default constructor.
 
         Parameters
         ----------
-        limits : list of 2 floats
+        limits : None or list of 2 floats
             2 limits resp. low and high
+        circular : bool or float
+            False not circular
+            True  circular with period from limits[0] to limits[1]
+            period of circularity
+        domain : 2 floats
+            over which the prior is defined
         prior : Prior
             prior to copy (with new limits if applicable)
         """
@@ -74,25 +107,22 @@ class Prior( object ):
 
         self.deltaP = 0.0001                # for numerical partials
         # private properties of the Prior
-        self._lowDomain = -math.inf         # Lower limit of the Priors possible domain.
-        self._highDomain = math.inf         # Upper limit of the Priors possible domain
+        self._lowDomain  = domain[0]         # Lower limit of the Priors possible domain.
+        self._highDomain = domain[1]         # Upper limit of the Priors possible domain
 
-        object.__setattr__( self, "lowLimit", -math.inf )       # Lower limit.
-        object.__setattr__( self, "highLimit", math.inf )       # Upper limit.
-
-        self.setLimits( limits )
+        self.setPriorAttributes( limits, circular )
 
         if prior is not None :
             self.deltaP = prior.deltaP
 
     def copy( self ) :
         """ Return a copy """
-        return Prior( prior=self, limits=self.limits )
+        return Prior( prior=self, limits=self.limits, circular=self.circular )
 
     def setLimits( self, limits=None ):
         """
         Set limits.
-        It is asserted that lowLimit is smaller than hoghLimit.
+        It is asserted that lowLimit is smaller than highLimit.
 
         Parameters
         ----------
@@ -105,19 +135,91 @@ class Prior( object ):
         ValueError when low limit is larger than high limit or out of Domain
 
         """
-        lowLimit  = None if limits is None else limits[0]
-        highLimit = None if limits is None else limits[1]
+#        print( "Prior 1 ", limits )
+        if limits is None :
+            self.lowLimit  = self._lowDomain
+            self.highLimit = self._highDomain
+            reset = False
+        else :
+            self.lowLimit  = limits[0] if limits[0] is not None else self._lowDomain
+            self.highLimit = limits[1] if limits[1] is not None else self._highDomain
+            reset = ( limits[0] is not None ) or ( limits[1] is not None )
 
-        if lowLimit is None :
-            lowLimit = self._lowDomain
-        if highLimit is None :
-            highLimit = self._highDomain
-
-        if not ( self._lowDomain <= lowLimit < highLimit <= self._highDomain ) :
+#        print( "Prior 2 ", self.lowLimit, self.highLimit )
+        if not ( self._lowDomain <= self.lowLimit < self.highLimit <= self._highDomain ) :
+            print( self._lowDomain, self.lowLimit, self.highLimit, self._highDomain )
             raise ValueError( "Limits out of order or out of domain" )
 
-        self.lowLimit  = lowLimit
-        self.highLimit = highLimit
+        try :
+            self._umin = 0.0            ## only for re-setting the limits
+            self._urng = 1.0
+            umax = self.domain2Unit( self.highLimit )
+            self._umin = self.domain2Unit( self.lowLimit )
+            self._urng = umax - self._umin
+        except :
+            self._urng = math.inf
+
+#        print( "Prior 3 ", self._umin, self._urng )
+
+        if math.isinf( self._urng ) :
+#            warnings.warn( "%s needs limits" % self.__str__() )
+            return
+
+        if hasattr( self, "baseUnit2Domain" ) : return			# aleady reset
+
+        # reset the functions
+        if reset :
+            setatt( self, "baseUnit2Domain", self.unit2Domain )
+            setatt( self, "unit2Domain", self.limitedUnit2Domain )
+            setatt( self, "baseDomain2Unit", self.domain2Unit )
+            setatt( self, "domain2Unit", self.limitedDomain2Unit )
+
+    def setPriorAttributes( self, limits, circular ) :
+
+        if isinstance( circular, bool ) :
+            self.setLimits( limits )
+            if circular and limits is not None :
+                period = limits[1] - limits[0]
+            else :
+                return
+        else :
+            period = circular
+
+            if hasattr( self, "center" ) :
+                self.setLimits( limits=[self.center - period / 2, self.center + period / 2] )
+            else :
+                self.setLimits( limits=[0,period] )
+
+        self.circular = circular
+
+        # reset the functions to circular variant
+        setatt( self, "unit2Domain", self.circularUnit2Domain )
+        setatt( self, "domain2Unit", self.circularDomain2Unit )
+
+
+    def isCircular( self ) :
+        """
+        Whether circular
+        """
+        return hasattr( self, "circular" ) and self.circular
+
+    def limitedDomain2Unit( self, dval ) :
+        """
+        Shrink domain to value in [0,1]
+        """
+        return ( self.baseDomain2Unit( dval ) - self._umin ) / self._urng
+
+    def limitedUnit2Domain( self, uval ) :
+        """
+        Expand value in [0,1] to domain
+        """
+        return self.baseUnit2Domain( uval * self._urng + self._umin )
+
+    def circularDomain2Unit( self, dval ) :
+        return ( self.limitedDomain2Unit( dval ) + 1 ) / 3
+
+    def circularUnit2Domain( self, uval ) :
+        return self.limitedUnit2Domain( ( uval * 3 ) % 1 )
 
     def __setattr__( self, name, value ) :
         """
@@ -127,15 +229,36 @@ class Prior( object ):
 
         """
         keys = ["lowLimit", "highLimit", "deltaP", "center", "scale",
-                "_lowDomain", "_highDomain"]
-        if name == "scale" and value <= 0 :
-            raise ValueError( "Scale must be positive" )
+                "_lowDomain", "_highDomain", "_umin", "_urng", "circular"]
+
+        if name == "scale"  and value <= 0 :
+            raise ValueError( "Attribute %s must be positive" % name )
 
         if name in keys :
-            object.__setattr__( self, name, float( value ) )
+            setatt( self, name, value )
         else :
             raise AttributeError( repr( self ) + " object has no attribute " + name )
 
+    def __getattr__( self, name ) :
+        """
+        Return (virtual) attribute with name
+
+        Parameters
+        ----------
+        name : str
+            name of attribute
+        """
+        if name == "lowLimit" :
+            return self._lowDomain
+        if name == "highLimit" :
+            return self._highDomain
+        if name == "limits" :
+            return self.getLimits()
+        if name == "circular" :			## when not defined
+            return False
+        else :
+            raise AttributeError( "Prior: Unknown attribute " + name )
+
     def unsetLimits( self ):
         """ Remove all limits.  """
         self.lowLimit = self._lowDomain
@@ -152,7 +275,8 @@ class Prior( object ):
         scale : float or None
             scale factor
         """
-        self.setLimits( limits=limits )
+        if limits is not None :
+            self.setLimits( limits=limits )
         if scale is not None :
             self.scale = scale
 
@@ -230,6 +354,7 @@ class Prior( object ):
         """ Return the range.  """
         return self.highLimit - self.lowLimit
 
+
     def domain2Unit( self, dval ):
         """
         Return a value in [0,1] given a value within the valid domain of
@@ -269,7 +394,6 @@ class Prior( object ):
 
         """
         return self.numPartialDomain2Unit( p )
-#        return 0.0 if self.isOutOfLimits( p ) else self.partialDomain2Unit( p )
 
     def partialDomain2Unit( self, p ):
         """
@@ -298,19 +422,6 @@ class Prior( object ):
         except :
             return -math.inf
 
-#    def partialDomain2Unit( self, dval ):
-        """
-        Return a the derivate of the domain2Unit function to dval.
-        By default: numeric derivative.
-
-        Parameters
-        ----------
-        dval : float
-            value within the domain of a parameter
-
-        """
-#        return self.numPartialDomain2Unit( dval )
-
     def numPartialDomain2Unit( self, dval ):
         """
         Return a the numeric derivate of the domain2Unit function to dval.
@@ -322,7 +433,7 @@ class Prior( object ):
 
         """
         return ( ( self.domain2Unit( dval + self.deltaP ) -
-                   self.domain2Unit( dval - self.deltaP) ) /
+                   self.domain2Unit( dval - self.deltaP ) ) /
                         ( 2 * self.deltaP ) )
 
     def partialLog( self, p ):
@@ -348,7 +459,7 @@ class Prior( object ):
 
         """
         if self.isOutOfLimits( p ) : return math.nan
-#        if math.isinf( p ) : return -p
+
         rm = self.logResult( p - self.deltaP )
         rp = self.logResult( p + self.deltaP )
         return ( rp - rm ) / ( 2 * self.deltaP )
@@ -359,7 +470,17 @@ class Prior( object ):
 
     def __str__( self ):
         """ Return a string representation of the prior.  """
-        pass
+
+        name = self.shortName()
+
+        if hasattr( self, "center" ) :
+            name += str( " at (%.2f %.2f)" % ( self.center, self.scale ) )
+
+        if self.hasLowLimit() or self.hasHighLimit():
+            name += str( " circular" if self.isCircular() else " with limits" )
+            name += str( " between %.2f and %.2f" % ( self.lowLimit, self.highLimit ) )
+
+        return name
 
 #      * End of Prior
 
