@@ -7,11 +7,11 @@ from .Dynamic import Dynamic
 from .Engine import Engine
 
 __author__ = "Do Kester"
-__year__ = 2017
+__year__ = 2020
 __license__ = "GPL3"
-__version__ = "0.9"
-__maintainer__ = "Do"
-__status__ = "Development"
+__version__ = "2.6.0"
+__url__ = "https://www.bayesicfitting.nl"
+__status__ = "Perpetual Beta"
 
 #  *
 #  * This file is part of the BayesicFitting package.
@@ -63,7 +63,7 @@ class StartEngine( Engine ):
         return str( "StartEngine" )
 
     #  *********EXECUTE***************************************************
-    def execute( self, walker, lowLhood ):
+    def execute( self, kw, lowLhood ):
         """
         Execute the engine by a random selection of the parameters.
 
@@ -79,6 +79,7 @@ class StartEngine( Engine ):
         int : the number of successfull moves
 
         """
+        walker = self.walkers[kw]
         problem = walker.problem
         model = problem.model
         fitIndex = walker.fitIndex
@@ -87,8 +88,9 @@ class StartEngine( Engine ):
         npar = len( allp )
         onp = problem.npars
 
+        maxtrials = self.maxtrials
         if hasattr( self.errdis, "constrain" ) and callable( self.errdis.constrain ) :
-            maxtrials = self.maxtrials * 100
+            maxtrials *= 100
         ktry = 0
         while True :
 
@@ -125,10 +127,12 @@ class StartEngine( Engine ):
             else :
                 ktry += 1
 
-        self.setWalker( walker, problem, allp, logL, fitIndex=fitIndex )
+        self.setWalker( walker.id, problem, allp, logL, fitIndex=fitIndex )
+
 
         wlkr = self.walkers[walker.id]
         wlkr.check( nhyp=self.errdis.nphypar )
+#        print( fmt( walker.id ), fmt( wlkr.allpars ), fmt( wlkr.logL ), fmt( allp ), fmt( logL ) )
 
         return len( fitIndex )
 
